@@ -64,11 +64,11 @@ class BaseInjector:
         self._client = Client(self.host)
         self.stickybeak_dir = Path.home() / ".stickybeak" / Path(f"{self.name}")
 
-    def connect(self, blocking: bool = True) -> None:
+    def connect(self, blocking: bool = True, timeout: float = 5.0) -> None:
         def target() -> None:
             try:
                 # ########## Get data
-                self._server_data = self._client.get(SERVER_DATA_ENDPOINT)
+                self._server_data = self._client.get(SERVER_DATA_ENDPOINT, timeout=timeout)
 
                 # ########## Collect remote code
                 sources: Dict[str, str] = self._server_data["source"]
@@ -235,7 +235,8 @@ class BaseInjector:
     ) -> object:
         self._raise_if_not_connected()
 
-        source: str = textwrap.dedent(inspect.getsource(klass))
+        source = self._get_class_source(klass)
+
         filename = inspect.getsourcefile(klass)
         offset = inspect.getsourcelines(klass)[1]
         ret = self._run_remote_fun(
@@ -243,12 +244,22 @@ class BaseInjector:
         )
         return ret
 
+    def _get_class_source(self, klass: type) -> str:
+        mro = reversed(klass.mro()[:-1])
+        sources = []
+
+        for c in mro:
+            sources.append(textwrap.dedent(inspect.getsource(c)) + "\n")
+
+        ret = "".join(sources)
+        return ret
+
     def klass(self, cls: type) -> type:
         # re execute class to get copy
         # this way original class can yield multiple injected classes
         # first_instance = injector1.klass(Klass)
         # second_instance = injector2.klass(Klass)
-        source: str = textwrap.dedent(inspect.getsource(cls))
+        source = self._get_class_source(cls)
 
         definition_module = sys.modules[cls.__module__]
         sandbox: Dict[str, Any] = {}
